@@ -1,6 +1,12 @@
 # coding: utf-8
 """Honeybee Door."""
 from __future__ import division
+import math
+
+from ladybug_geometry.geometry2d.pointvector import Vector2D
+from ladybug_geometry.geometry3d.pointvector import Point3D
+from ladybug_geometry.geometry3d.face import Face3D
+from ladybug.color import Color
 
 from ._basewithshade import _BaseWithShade
 from .typing import clean_string
@@ -9,12 +15,6 @@ from .boundarycondition import boundary_conditions, Outdoors, Surface
 from .shade import Shade
 import honeybee.writer.door as writer
 
-from ladybug_geometry.geometry2d.pointvector import Vector2D
-from ladybug_geometry.geometry3d.pointvector import Point3D
-from ladybug_geometry.geometry3d.face import Face3D
-
-import math
-
 
 class Door(_BaseWithShade):
     """A single planar Door in a Face.
@@ -50,9 +50,19 @@ class Door(_BaseWithShade):
         * max
         * altitude
         * azimuth
+        * type_color
+        * bc_color
         * user_data
     """
     __slots__ = ('_geometry', '_parent', '_boundary_condition', '_is_glass')
+    TYPE_COLORS = {
+        False: Color(160, 150, 100),
+        True: Color(128, 204, 255, 100)
+    }
+    BC_COLORS = {
+        'Outdoors': Color(128, 204, 255),
+        'Surface': Color(0, 190, 0)
+    }
 
     def __init__(self, identifier, geometry, boundary_condition=None, is_glass=False):
         """A single planar Door in a Face."""
@@ -255,6 +265,16 @@ class Door(_BaseWithShade):
         """
         return math.degrees(self._geometry.azimuth)
 
+    @property
+    def type_color(self):
+        """Get a Color to be used in visualizations by type."""
+        return self.TYPE_COLORS[self.is_glass]
+
+    @property
+    def bc_color(self):
+        """Get a Color to be used in visualizations by boundary condition."""
+        return self.BC_COLORS[self.boundary_condition.name]
+
     def horizontal_orientation(self, north_vector=Vector2D(0, 1)):
         """Get a number between 0 and 360 for the orientation of the door in degrees.
 
@@ -449,6 +469,23 @@ class Door(_BaseWithShade):
                 'Door "{}" is invalid with dimensions less than the '
                 'tolerance.\n{}'.format(self.full_id, e))
 
+    def is_geo_equivalent(self, door, tolerance=0.01):
+        """Get a boolean for whether this object is geometrically equivalent to another.
+
+        The total number of vertices and the ordering of these vertices can be
+        different but the geometries must share the same center point and be
+        next to one another to within the tolerance.
+
+        Args:
+            door: Another Door for which geometric equivalency will be tested.
+            tolerance: The minimum difference between the coordinate values of two
+                vertices at which they can be considered geometrically equivalent.
+
+        Returns:
+            True if geometrically equivalent. False if not geometrically equivalent.
+        """
+        return self.geometry.is_centered_adjacent(door.geometry, tolerance)
+
     def check_planar(self, tolerance=0.01, raise_exception=True, detailed=False):
         """Check whether all of the Door's vertices lie within the same plane.
 
@@ -530,6 +567,13 @@ class Door(_BaseWithShade):
                 error_type='Zero-Area Geometry')
         return [] if detailed else ''
 
+    def display_dict(self):
+        """Get a list of DisplayFace3D dictionaries for visualizing the object."""
+        base = [self._display_face(self.geometry, self.type_color)]
+        for shd in self.shades:
+            base.extend(shd.display_dict())
+        return base
+
     @property
     def to(self):
         """Door writer object.
